@@ -14,7 +14,7 @@
 #' @param quali Defines whether the factor is quantitative or qualitative (\emph{qualitative})
 #' @param alpha.f Level of significance of the F test (\emph{default} is 0.05)
 #' @param alpha.t Significance level of the multiple comparison test (\emph{default} is 0.05)
-#' @param grau Polynomial degree in case of quantitative factor (\emph{default} is 1). Provide a vector with three elements.
+#' @param grau Polynomial degree in case of quantitative factor (\emph{default} is 1). Provide a vector with two elements.
 #' @param grau12 Polynomial degree in case of quantitative factor (\emph{default} is 1). Provide a vector with n levels of factor 2, in the case of interaction f1 x f2 and qualitative factor 2 and quantitative factor 1.
 #' @param grau21 Polynomial degree in case of quantitative factor (\emph{default} is 1). Provide a vector with n levels of factor 1, in the case of interaction f1 x f2 and qualitative factor 1 and quantitative factor 2.
 #' @param transf Applies data transformation (default is 1; for log consider 0; `angular` for angular transformation)
@@ -39,7 +39,7 @@
 #' @param color Column chart color (\emph{default} is "rainbow")
 #' @param posi legend position
 #' @param ylim y-axis scale
-#' @param point if quali=F, defines whether to plot all points ("all"), mean ("mean"), standard deviation ("mean_sd") or mean with standard error (\emph{default} - "mean_se").
+#' @param point This function defines whether the point must have all points ("all"), mean ("mean"), standard deviation (\emph{default} - "mean_sd") or mean with standard error ("mean_se") if quali= FALSE. For quali=TRUE, `mean_sd` and `mean_se` change which information will be displayed in the error bar.
 #' @param angle.label label angle
 #' @note The order of the chart follows the alphabetical pattern. Please use `scale_x_discrete` from package ggplot2, `limits` argument to reorder x-axis. The bars of the column and segment graphs are standard deviation.
 #' @note The function does not perform multiple regression in the case of two quantitative factors.
@@ -83,7 +83,7 @@ FAT2DBC.ad=function(f1,
                     alpha.t=0.05,
                     quali=c(TRUE,TRUE),
                     mcomp="tukey",
-                    grau=c(NA,NA), # isolado e interação tripla
+                    grau=c(NA,NA),
                     grau12=NA, # F1/F2
                     grau21=NA, # F2/F1
                     transf=1,
@@ -166,11 +166,13 @@ FAT2DBC.ad=function(f1,
   col3 <- c(resp, respAd)
   tabF2ad <- data.frame(TRAT2 = col1, REP = col2, RESP2 = col3)
   TRAT2 <- factor(tabF2ad[, 1])
-  anavaf1 <- aov(tabF2ad[, 3] ~ TRAT2)
+  REP <- factor(tabF2ad$REP)
+  anavaf1 <- aov(tabF2ad[, 3] ~ TRAT2+REP)
   anavaTr <- summary(anavaf1)[[1]]
-  anava1=rbind(anava,anavaTr)
+  anava1=rbind(anava,anavaTr[c(1,3),])
+  anava1[3,]=anavaTr[2,]
   anava1$Df[5]=1
-  anava1$`Sum Sq`[5]=anava1$`Sum Sq`[5]-sum(anava1$`Sum Sq`[c(1:3)])
+  anava1$`Sum Sq`[5]=anava1$`Sum Sq`[5]-sum(anava1$`Sum Sq`[c(1,2,4)])
   anava1$`Mean Sq`[5]=anava1$`Sum Sq`[5]/anava1$Df[5]
   anava1$`F value`[1:5]=anava1$`Mean Sq`[1:5]/anava1$`Mean Sq`[6]
   for(i in 1:nrow(anava1)-1){
@@ -321,9 +323,13 @@ FAT2DBC.ad=function(f1,
           if(transf !=1){letra1$respo=tapply(response,fatores[,i],mean, na.rm=TRUE)[rownames(letra1)]}}
         print(letra1)
         ordem=unique(as.vector(unlist(fatores[i])))
+        #=====================================================
+        if(point=="mean_sd"){desvio=tapply(response, c(fatores[i]), sd, na.rm=TRUE)[ordem]}
+        if(point=="mean_se"){desvio=(tapply(response, c(fatores[i]), sd, na.rm=TRUE)/
+                                       sqrt(tapply(response, c(fatores[i]), length)))[ordem]}
         dadosm=data.frame(letra1[ordem,],
                           media=tapply(response, c(fatores[i]), mean, na.rm=TRUE)[ordem],
-                          desvio=tapply(response, c(fatores[i]), sd, na.rm=TRUE)[ordem])
+                          desvio=desvio)
         dadosm$trats=factor(rownames(dadosm),levels = ordem)
         dadosm$limite=dadosm$media+dadosm$desvio
         lim.y=dadosm$limite[which.max(abs(dadosm$limite))]
@@ -678,7 +684,11 @@ FAT2DBC.ad=function(f1,
     }
     if(quali[1] & quali[2]==TRUE){
       media=tapply(response,list(Fator1,Fator2), mean, na.rm=TRUE)
-      desvio=tapply(response,list(Fator1,Fator2), sd, na.rm=TRUE)
+      # desvio=tapply(response,list(Fator1,Fator2), sd, na.rm=TRUE)
+      if(point=="mean_sd"){desvio=tapply(response,list(Fator1,Fator2), sd, na.rm=TRUE)}
+      if(point=="mean_se"){desvio=tapply(response,list(Fator1,Fator2), sd, na.rm=TRUE)/
+        sqrt(tapply(response,list(Fator1,Fator2), length))}
+
       graph=data.frame(f1=rep(rownames(media),length(colnames(media))),
                        f2=rep(colnames(media),e=length(rownames(media))),
                        media=as.vector(media),
